@@ -1,5 +1,5 @@
 package HTTP::API::Client;
-$HTTP::API::Client::VERSION = '0.07';
+$HTTP::API::Client::VERSION = '0.08';
 use strict;
 use warnings;
 
@@ -12,7 +12,7 @@ HTTP::API::Client - API Client
  use HTTP::API::Client;
 
  my $ua1 = HTTP::API::Client->new;
- my $ua2 = HTTP::API::Client->new(base_url => URI->new( $url ), pre_deinfed_headers => { X_COMPANY => 'ABC LTD' } );
+ my $ua2 = HTTP::API::Client->new(base_url => URI->new( $url ), pre_defined_headers => { X_COMPANY => 'ABC LTD' } );
  my $ua3 = HTTP::API::Client->new(base_url => URI->new( $url ), pre_defined_data => { api_key => 123 } );
 
  $ua->send( $method, $url, \%data, \%header );
